==> zip-2.8.71.tgz: package/README.md <==
Combines values from arrays. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Similar: [cartesianProduct], [zip].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.zip(xs, [fm], [ft], [vd]);
// xs: arrays
// fm: map function (vs, i, xs)
// ft: till function (dones) (some)
// vd: default value
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3];
var y = [4, 5];
array.zip([x, y]);
// [ [ 1, 4 ], [ 2, 5 ] ] (shortest)

array.zip([x, y], ([a, b]) => a + b);
// [ 5, 7 ]

array.zip([x, y], null, array.some);
// [ [ 1, 4 ], [ 2, 5 ] ] (shortest)

array.zip([x, y], null, array.every, 0);
// [ [ 1, 4 ], [ 2, 5 ], [ 3, 0 ] ] (longest)

array.zip([x, y], null, array.head, 0);
// [ [ 1, 4 ], [ 2, 5 ], [ 3, 0 ] ] (first)
```

### references

- [Data.List.zipWith: Haskell](http://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:zipWith)
- [List-Extra.zip: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#zip)
- [zip: Python](https://www.programiz.com/python-programming/methods/built-in/zip)
- [itertools.zip_longest: Python](https://docs.python.org/3/library/itertools.html#itertools.zip_longest)
- [zip: Ruby](https://apidock.com/ruby/Array/zip)
- [_.zip: lodash](https://lodash.com/docs/4.17.15#zip)
- [_.zipWith: lodash](https://lodash.com/docs/4.17.15#zipWith)
- [Array.zip: sugarjs](https://sugarjs.com/docs/#/Array/zip)

[cartesianProduct]: https://github.com/nodef/extra-array/wiki/cartesianProduct
[zip]: https://github.com/nodef/extra-array/wiki/zip
[:running:]: https://npm.runkit.com/@extra-array/zip
[:package:]: https://www.npmjs.com/package/@extra-array/zip
[:moon:]: https://www.npmjs.com/package/@extra-array/zip.min
[:ledger:]: https://unpkg.com/@extra-array/zip/
[:vhs:]: https://asciinema.org/a/332154

==> zip-2.10.0.tgz: package/README.md <==
Combines values from arrays. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Similar: [cartesianProduct], [zip].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.zip(xs, [fm], [ft], [vd]);
// xs: arrays
// fm: map function (vs, i)
// ft: till function (dones) (some)
// vd: default value
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3];
var y = [4, 5];
array.zip([x, y]);
// [ [ 1, 4 ], [ 2, 5 ] ] (shortest)

array.zip([x, y], ([a, b]) => a + b);
// [ 5, 7 ]

array.zip([x, y], null, array.some);
// [ [ 1, 4 ], [ 2, 5 ] ] (shortest)

array.zip([x, y], null, array.every, 0);
// [ [ 1, 4 ], [ 2, 5 ], [ 3, 0 ] ] (longest)

array.zip([x, y], null, array.head, 0);
// [ [ 1, 4 ], [ 2, 5 ], [ 3, 0 ] ] (first)
```

### references

- [Data.List.zipWith: Haskell](http://hackage.haskell.org/package/base-4.12.0.0/docs/Data-List.html#v:zipWith)
- [List-Extra.zip: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#zip)
- [zip: Python](https://www.programiz.com/python-programming/methods/built-in/zip)
- [itertools.zip_longest: Python](https://docs.python.org/3/library/itertools.html#itertools.zip_longest)
- [zip: Ruby](https://apidock.com/ruby/Array/zip)
- [_.zip: lodash](https://lodash.com/docs/4.17.15#zip)
- [_.zipWith: lodash](https://lodash.com/docs/4.17.15#zipWith)
- [Array.zip: sugarjs](https://sugarjs.com/docs/#/Array/zip)

[cartesianProduct]: https://github.com/nodef/extra-array/wiki/cartesianProduct
[zip]: https://github.com/nodef/extra-array/wiki/zip
[:running:]: https://npm.runkit.com/@extra-array/zip
[:package:]: https://www.npmjs.com/package/@extra-array/zip
[:moon:]: https://www.npmjs.com/package/@extra-array/zip.min
[:ledger:]: https://unpkg.com/@extra-array/zip/
[:vhs:]: https://asciinema.org/a/332154
